
from tensorflow.python.keras.preprocessing.text import Tokenizer
from tensorflow.python.keras.preprocessing.sequence import pad_sequences
from keras.models import load_model
import pickle
import os
this_dir, this_filename = os.path.split(__file__)
tokenizerpath = os.path.join(this_dir, "tokenizers", "tokenizer_deda.pickle")

weigthpath = os.path.join(this_dir, "weights", "model_deda.h5")


def check_de(string):
    with open(tokenizerpath, 'rb') as handle:
        turkish_tokenizer = pickle.load(handle)
    model = load_model(weigthpath)
    tokens = turkish_tokenizer.texts_to_sequences(string)
    tokens_pad = pad_sequences(tokens, maxlen=7)
    print(tokens)




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="trylmz1",
    version="0.0.2",
    author="Ümit Yılmaz",
    author_email="umitylmz98@gmail.com",
    description="This is a deep learning based library for handling Turkish clitics such as da, de, ki and mi.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
          'tensorflow',
          'keras',
      ],
)
